@@ -23,10 +23,21 @@
 
 """Basic test suite for the scanner."""
 
+from zapf.device import typecode_description
+
 from zapf.scan import Scanner
 
 
 def test_scan(plc_io):
     scanner = Scanner(plc_io, plc_io.log)
-    for it in scanner.scan_devices():
-        print(it)
+
+    plc_data = scanner.get_plc_data()
+    assert plc_data.indexer_addr == 64
+    assert plc_data.indexer_size == 36
+    assert plc_data.plc_name == 'lazy test plc'
+    assert plc_data.plc_author == 'anonymous\ncoward'
+    assert plc_data.plc_version == '0.0.1alpha'
+
+    for devinfo in scanner.scan_devices():
+        # the test devices have the same name as the typecode description
+        assert typecode_description(devinfo.typecode) == devinfo.name
