@@ -587,9 +587,9 @@ def typecode_description(typecode):
     name = typeinfo.devcls.__name__
     valuesize = calcsize(typeinfo.value_fmt)
     if typeinfo.num_params > 0 and not typeinfo.has_pctrl:
-        name += f' ({typeinfo.num_params})'
+        name += f'/{typeinfo.num_params}'
     if typeinfo.num_values > 1:
-        name += f' ({typeinfo.num_values})'
+        name += f'/{typeinfo.num_values}'
     if typecode in (0x1b03, 0x1f05):
         name += ' (32 bit, legacy)'
     else:
